/*
                              Recycle Bin Purge
 */

#ifndef EDV_RECBIN_PURGE_H
#define EDV_RECBIN_PURGE_H

#include <gtk/gtk.h>

#include "edv_types.h"
#include "edv_recycled_obj.h"


extern const gchar *EDVRecBinPurgeGetError(edv_core_struct *core);

extern gint EDVRecBinPurge(
	edv_core_struct *core,
	const guint index,		/* Index of the recycled object */
	GtkWidget *toplevel,
	const gfloat progress_value,	/* Can be -1.0 */
	gboolean show_progress, gboolean interactive,
	gboolean *yes_to_all
);
extern gint EDVRecBinPurgeAll(
	edv_core_struct *core,
	GtkWidget *toplevel,
	gboolean show_progress, gboolean interactive,
	gboolean *yes_to_all
);


#endif	/* EDV_RECBIN_PURGE_H */
